@@ -5,7 +5,6 @@ import { K8sEntityMap } from '@console/shared/src';
 import { getBasicID, prefixedID } from '../../utils';
 import { vmDescriptionModal } from '../modals/vm-description-modal';
 import { BootOrderModal } from '../modals/boot-order-modal';
-import { VMCDRomModal } from '../modals/cdrom-vm-modal/vm-cdrom-modal';
 import dedicatedResourcesModal from '../modals/scheduling-modals/dedicated-resources-modal/connected-dedicated-resources-modal';
 import tolerationsModal from '../modals/scheduling-modals/tolerations-modal/connected-tolerations-modal';
 import nodeSelectorModal from '../modals/scheduling-modals/node-selector-modal/connected-node-selector-modal';
@@ -13,7 +12,6 @@ import affinityModal from '../modals/scheduling-modals/affinity-modal/connected-
 import { getRowsDataFromAffinity } from '../modals/scheduling-modals/affinity-modal/helpers';
 import { getDescription } from '../../selectors/selectors';
 import {
-  getCDRoms,
   getFlavor,
   getWorkloadProfile,
   isDedicatedCPUPlacement,
@@ -22,7 +20,6 @@ import { getTemplateOperatingSystems } from '../../selectors/vm-template/advance
 import { vmFlavorModal } from '../modals';
 import { EditButton } from '../edit-button';
 import { VMDetailsItem } from '../vms/vm-resource';
-import { DiskSummary } from '../vm-disks/disk-summary';
 import { asVM, getDevices } from '../../selectors/vm';
 import { BootOrderSummary } from '../boot-order';
 import { V1alpha1DataVolume } from '../../types/vm/disk/V1alpha1DataVolume';
@@ -94,14 +91,9 @@ export const VMTemplateResourceSummary: React.FC<VMTemplateResourceSummaryProps>
 export const VMTemplateDetailsList: React.FC<VMTemplateResourceListProps> = ({
   template,
   dataVolumeLookup,
-  canUpdateTemplate,
 }) => {
-  const [isBootOrderModalOpen, setBootOrderModalOpen] = React.useState<boolean>(false);
-
-  const vm = asVM(template);
   const id = getBasicID(template);
   const devices = getDevices(template);
-  const cds = getCDRoms(vm);
 
   return (
     <dl className="co-m-pane__details">
@@ -109,28 +101,12 @@ export const VMTemplateDetailsList: React.FC<VMTemplateResourceListProps> = ({
         title="Boot Order"
         canEdit
         editButtonId={prefixedID(id, 'boot-order-edit')}
-        onEditClick={() => setBootOrderModalOpen(true)}
+        onEditClick={() => BootOrderModal({ vmLikeEntity: template, modalClassName: 'modal-lg' })}
         idValue={prefixedID(id, 'boot-order')}
       >
-        <BootOrderModal
-          isOpen={isBootOrderModalOpen}
-          setOpen={setBootOrderModalOpen}
-          vmLikeEntity={template}
-        />
         <BootOrderSummary devices={devices} />
       </VMDetailsItem>
 
-      <VMDetailsItem
-        title="CD-ROMs"
-        canEdit={canUpdateTemplate}
-        editButtonId={prefixedID(id, 'cdrom-edit')}
-        onEditClick={() => VMCDRomModal({ vmLikeEntity: template, modalClassName: 'modal-lg' })}
-        idValue={prefixedID(id, 'cdrom')}
-        isNotAvail={cds.length === 0}
-      >
-        <DiskSummary disks={cds} vm={asVM(template)} />
-      </VMDetailsItem>
-
       <VMDetailsItem title="Provision Source" idValue={prefixedID(id, 'provisioning-source')}>
         <TemplateSource template={template} dataVolumeLookup={dataVolumeLookup} detailed />
       </VMDetailsItem>
@@ -242,7 +218,7 @@ export const VMTemplateSchedulingList: React.FC<VMTemplateResourceSummaryProps>
 type VMTemplateResourceListProps = {
   template: TemplateKind;
   dataVolumeLookup: K8sEntityMap<V1alpha1DataVolume>;
-  canUpdateTemplate: boolean;
+  canUpdateTemplate?: boolean;
 };
 
 type VMTemplateResourceSummaryProps = {
